@@ -304,7 +304,7 @@ def _wait_postgres(config, timeout=600):
         click.secho("Postgres now available.", fg="green")
 
 
-def _is_container_running(machine_name):
+def _is_container_running(config, machine_name):
     import docker
 
     container_id = __dc_out(config, ["ps", "-q", machine_name]).strip()
@@ -321,10 +321,10 @@ def _is_container_running(machine_name):
     return False
 
 
-def is_up(*machine_name):
+def is_up(config, *machine_name):
     assert len(machine_name) == 1
     click.echo(
-        "Running" if _is_container_running(machine_name[0]) else "Not Running",
+        "Running" if _is_container_running(config, machine_name[0]) else "Not Running",
         machine_name[0],
     )
 
@@ -1140,10 +1140,13 @@ def _binary_zip(folder, destpath):
         raise Exception(f"file {destpath} not generated")
 
 @contextmanager
-def autocleanpaper(filepath=None):
-    filepath = Path(filepath or tempfile._get_default_tempdir()) / next(
-        tempfile._get_candidate_names()
-    )
+def autocleanpaper(filepath=None, strict=False):
+    if strict:
+        assert filepath
+    else:
+        filepath = Path(filepath or tempfile._get_default_tempdir()) / next(
+            tempfile._get_candidate_names()
+        )
 
     try:
         yield filepath
@@ -1322,4 +1325,7 @@ def _shell_complete_file(ctx, param, incomplete):
 
 def ensure_project_name(config):
     if not config.project_name:
-        raise click.Abort("Project name missing.")
\ No newline at end of file
+        raise click.Abort("Project name missing.")
+
+def _get_filestore_folder(config):
+    return config.dirs["odoo_data_dir"] / "filestore" / config.dbname
